# Samples

Here are samples to test cx_Freeze or to show how to use a package in cx_Freeze.

# Installation and requirements:

In a virtual environment, install by issuing the command:

```
pip install --upgrade cx_Freeze PyQt6-WebEngine
```

# Support for inclusion of extra plugins:

Please check the setup.py as example on how to use this feature.
